@@ -60,7 +60,7 @@ static inline void dvb_mjd_get(uint16_t mjd, int *y, int *m, int *d)
 {
     int k;
     int yp = (mjd * 20 - 301564) / 7305;
-    int mp = (mjd * 10000 - 149561000 - yp * 3652500) / 306001;
+    int mp = (mjd * 10000 - 149561000 - 10000 * (yp * 1461 / 4)) / 306001;
     *d = mjd - 14956 - yp * 1461 / 4 - mp * 306001 / 10000;
     k = (mp == 14 || mp == 15) ? 1 : 0;
     *y = yp + k;
@@ -75,6 +75,13 @@ static inline void dvb_time_decode_bcd(uint32_t bcd, int *seconds, int *hour, in
     if (seconds)
         *seconds = *hour * 3600 + *min * 60 + *sec;
 }
+
+static inline void dvb_time_decode_bcd16(uint16_t bcd, int *seconds, int *hour, int *min) {
+    *hour = bcd2dec( (bcd >>  8) & 0xff );
+    *min  = bcd2dec(  bcd        & 0xff );
+    if (seconds)
+        *seconds = *hour * 3600 + *min * 60;
+}
 #undef bcd2dec
 
 static inline time_t dvb_time_decode_UTC(uint64_t UTC_time) {
@@ -122,6 +129,18 @@ static inline uint32_t dvb_time_encode_duration(unsigned int duration_sec)
 
     return ret;
 }
+
+static inline uint32_t dvb_time_encode_duration16(unsigned int duration_min)
+{
+    unsigned int t_min, t_hour, ret;
+    t_min  = duration_min % 60;
+    t_hour = duration_min / 60;
+
+    ret  = dec2bcd(t_hour) << 8;
+    ret |= dec2bcd(t_min );
+
+    return ret;
+}
 #undef dec2bcd
 
 static inline time_t dvb_time_format_UTC(uint64_t UTC_time, struct tm *tm, char *output) {
